Genesis2
========

The Genesis2 Chip Generator (CG) is a design system and meta-programming language for automatically producing custom hardware.

Genesis2 is free software as governed by a BSD-style license, see LICENSE.txt for specific terms and conditions.

For more information see <https://github.com/StanfordVLSI/Genesis2/wiki>
